==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountSpecFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class APIRequestCountSpecFluent<A extends APIRequestCountSpecFluent<A>> extends BaseFluent<A>{
  public APIRequestCountSpecFluent() {
  }
  public APIRequestCountSpecFluent(APIRequestCountSpec instance) {
    instance = (instance != null ? instance : new APIRequestCountSpec());

    if (instance != null) {
      this.withNumberOfUsersToReport(instance.getNumberOfUsersToReport());
      this.withNumberOfUsersToReport(instance.getNumberOfUsersToReport());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Long numberOfUsersToReport;
  private Map<String,Object> additionalProperties;
  public Long getNumberOfUsersToReport() {
    return this.numberOfUsersToReport;
  }
  public A withNumberOfUsersToReport(Long numberOfUsersToReport) {
    this.numberOfUsersToReport=numberOfUsersToReport; return (A) this;
  }
  public boolean hasNumberOfUsersToReport() {
    return this.numberOfUsersToReport != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    APIRequestCountSpecFluent that = (APIRequestCountSpecFluent) o;
    if (!java.util.Objects.equals(numberOfUsersToReport, that.numberOfUsersToReport)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(numberOfUsersToReport,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (numberOfUsersToReport != null) { sb.append("numberOfUsersToReport:"); sb.append(numberOfUsersToReport + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountSpecFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class APIRequestCountSpecFluent<A extends APIRequestCountSpecFluent<A>> extends BaseFluent<A>{
  public APIRequestCountSpecFluent() {
  }
  
  public APIRequestCountSpecFluent(APIRequestCountSpec instance) {
    this.copyInstance(instance);
  }
  private Long numberOfUsersToReport;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(APIRequestCountSpec instance) {
    instance = (instance != null ? instance : new APIRequestCountSpec());
  
    if (instance != null) {
        this.withNumberOfUsersToReport(instance.getNumberOfUsersToReport());
        this.withNumberOfUsersToReport(instance.getNumberOfUsersToReport());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Long getNumberOfUsersToReport() {
    return this.numberOfUsersToReport;
  }
  
  public A withNumberOfUsersToReport(Long numberOfUsersToReport) {
    this.numberOfUsersToReport=numberOfUsersToReport; return (A) this;
  }
  
  public boolean hasNumberOfUsersToReport() {
    return this.numberOfUsersToReport != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    APIRequestCountSpecFluent that = (APIRequestCountSpecFluent) o;
    if (!java.util.Objects.equals(numberOfUsersToReport, that.numberOfUsersToReport)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(numberOfUsersToReport,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (numberOfUsersToReport != null) { sb.append("numberOfUsersToReport:"); sb.append(numberOfUsersToReport + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
